@@ -25,7 +25,7 @@ class PlotmanCollector:
 
     def collect(self):
         cfg = configuration.get_validated_configs()
-        jobs = Job.get_running_jobs(cfg.directories.log)
+        jobs = Job.genTasks(cfg.directories.log)
         count = len(sorted(jobs, key=job.Job.get_time_wall))
         yield GaugeMetricFamily("plotman_jobs_count", "Number of plotting jobs running", value=count)
 
@@ -51,7 +51,7 @@ class MainHandler(web.RequestHandler):
         remote_addr = os.environ.get('REMOTE_ADDR', '-')
         ts = datetime.now().strftime('%m-%d %H:%M:%S')
 
-        con = sqlite3.connect(get_db_path)
+        con = sqlite3.connect(get_db_path())
         cur = con.cursor()
 
         cur.execute('''CREATE TABLE IF NOT EXISTS systemchia (
