@@ -131,12 +131,12 @@ def plotting(cfg: PlotmanConfig):
 def archivePlots(cfg: any):
     print('...starting archive loop')
     firstit = True
-    jobs = Job.get_running_jobs(cfg.directories.log)
+    jobs = Job.genTasks(cfg.directories.log)
     while True:
         if not firstit:
             print('Sleeping 60s until next iteration...')
             time.sleep(60)
-            jobs = Job.get_running_jobs(cfg.directories.log)
+            jobs = Job.genTasks(cfg.directories.log)
         firstit = False
         archiving_status, log_message = archive.spawn_archive_process_rsync(cfg.directories, jobs)
         if log_message:
@@ -196,8 +196,6 @@ def main():
     #
     if args.cmd == 'plot':
         plotting(cfg)
-        # with concurrent.futures.ThreadPoolExecutor(max_workers=10) as executor:
-        #    executor.submit(plotting, cfg)
 
     #
     # Analysis of completed jobs
@@ -208,7 +206,7 @@ def main():
                          args.bytmp, args.bybitfield)
 
     else:
-        jobs = Job.get_running_jobs(cfg.directories.log)
+        jobs = Job.genTasks(cfg.directories.log)
 
         # Status report
         if args.cmd == 'status':
